@@ -8,7 +8,7 @@ require Exporter;
 use warnings;
 use strict;
 use Carp;
-our $VERSION = '0.19_05';
+our $VERSION = '0.24_01';
 require XSLoader;
 XSLoader::load (__PACKAGE__, $VERSION);
 
@@ -25,12 +25,28 @@ sub valid_json
 {
     my ($json) = @_;
     if (! $json) {
-	return undef;
+	return 0;
     }
+    my $r;
     eval {
-	parse_json (@_);
+	$r = validate_json (@_);
     };
-    return ! $@;
+    if ($@ or ! $r) {
+	return 0;
+    }
+    return 1;
+}
+
+sub json_file_to_perl
+{
+    my ($file_name) = @_;
+    my $json = '';
+    open my $in, "<:encoding(utf8)", $file_name or croak $!;
+    while (<$in>) {
+	$json .= $_;
+    }
+    close $in or croak $!;
+    return json_to_perl ($json);
 }
 
 1;
